==> jc-1.4.0.tar.gz: soot/tagkit/StringTag.h <==
// public class soot.tagkit.StringTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 25504195378c79cb soot_tagkit_StringTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_StringTag_H_
#define _JC_soot_tagkit_StringTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_StringTag$sub_refs	_jc_soot_tagkit_StringTag$sub_refs;
typedef struct _jc_soot_tagkit_StringTag$sub_nonrefs	_jc_soot_tagkit_StringTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_StringTag$refs	_jc_soot_tagkit_StringTag$refs;
typedef struct _jc_soot_tagkit_StringTag$nonrefs	_jc_soot_tagkit_StringTag$nonrefs;
typedef struct _jc_soot_tagkit_StringTag$object	_jc_soot_tagkit_StringTag$object;

typedef const struct _jc_soot_tagkit_StringTag$vmethods	_jc_soot_tagkit_StringTag$vmethods;
typedef const struct _jc_soot_tagkit_StringTag$vtable	_jc_soot_tagkit_StringTag$vtable;
typedef const struct _jc_soot_tagkit_StringTag$vtype	_jc_soot_tagkit_StringTag$vtype;

// Constructors
extern void _jc_soot_tagkit_StringTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_tagkit_StringTag$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StringTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_StringTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_StringTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_StringTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StringTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_StringTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_StringTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_StringTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_StringTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_StringTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_StringTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_StringTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_StringTag$object *);
};

// Vtable
struct _jc_soot_tagkit_StringTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_StringTag$vmethods	soot_tagkit_StringTag;
};

// Vtype
struct _jc_soot_tagkit_StringTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_StringTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_StringTag$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_StringTag$refs {
    _jc_soot_tagkit_StringTag$sub_refs	soot_tagkit_StringTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_StringTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_StringTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_StringTag$sub_nonrefs	soot_tagkit_StringTag;
};

// Object instance structure
struct _jc_soot_tagkit_StringTag$object {
	_jc_soot_tagkit_StringTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_StringTag$vtype	*vtype;
	_jc_soot_tagkit_StringTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_StringTag$vtype _jc_soot_tagkit_StringTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_StringTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_StringTag$class_object;

#endif	/* _JC_soot_tagkit_StringTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/StringTag.h <==
// public class soot.tagkit.StringTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 25504195378c79cb soot_tagkit_StringTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_StringTag_H_
#define _JC_soot_tagkit_StringTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_StringTag$sub_refs	_jc_soot_tagkit_StringTag$sub_refs;
typedef struct _jc_soot_tagkit_StringTag$sub_nonrefs	_jc_soot_tagkit_StringTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_StringTag$refs	_jc_soot_tagkit_StringTag$refs;
typedef struct _jc_soot_tagkit_StringTag$nonrefs	_jc_soot_tagkit_StringTag$nonrefs;
typedef struct _jc_soot_tagkit_StringTag$object	_jc_soot_tagkit_StringTag$object;

typedef const struct _jc_soot_tagkit_StringTag$vmethods	_jc_soot_tagkit_StringTag$vmethods;
typedef const struct _jc_soot_tagkit_StringTag$vtable	_jc_soot_tagkit_StringTag$vtable;
typedef const struct _jc_soot_tagkit_StringTag$vtype	_jc_soot_tagkit_StringTag$vtype;

// Constructors
extern void _jc_soot_tagkit_StringTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_tagkit_StringTag$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StringTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_StringTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_StringTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_StringTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StringTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_StringTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_StringTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_StringTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_StringTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_StringTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_StringTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_StringTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_StringTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_StringTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_StringTag$vmethods	soot_tagkit_StringTag;
};

// Vtype
struct _jc_soot_tagkit_StringTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_StringTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_StringTag$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_StringTag$refs {
    _jc_soot_tagkit_StringTag$sub_refs	soot_tagkit_StringTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_StringTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_StringTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_StringTag$sub_nonrefs	soot_tagkit_StringTag;
};

// Object instance structure
struct _jc_soot_tagkit_StringTag$object {
	_jc_soot_tagkit_StringTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_StringTag$vtype	*vtype;
	_jc_soot_tagkit_StringTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_StringTag$vtype _jc_soot_tagkit_StringTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_StringTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_StringTag$class_object;

#endif	/* _JC_soot_tagkit_StringTag_H_ */
